

Authors
=======

Thank you for supporting RocketUnits.

Development Lead
----------------

* `Charlie Taylor <https://github.com/sonofeft>`_


Initial Project Layout
----------------------

RocketUnits Framework was Created by: `PyHatch <http://pyhatch.readthedocs.org/en/latest/>`_ 

(PyHatch Initializes Files And Directory Structures For New Python Projects.)

See PyHatch Docs at: `<http://pyhatch.readthedocs.org/en/latest/>`_

Tkinter Application
-------------------

The **RocketUnits** tkinter application was created with
`TkGridGUI <https://sonofefttkgridgui.readthedocs.io/en/latest/>`_.

TkGridGUI is a graphic user interface for creating python Tkinter applications.

The user creates a fully "wired" python Tkinter GUI application by placing widgets 
into a hierarchical grid structure.

TkGridGUI generates python source code for all the basic Tkinter widgets, Button,
Label and Entry, as well structures such as menus, notebooks and statusbars. 
Within the generated python source code, user application code is placed in
designated areas.

Common widget bindings, keyboard shortcuts and StringVar objects are 
created by default.

The workflow moves between placing widgets, editing widget properties, adding 
application logic to the generated python source code and testing the application 
after each change.